@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0208';
+$VERSION = '2.0209';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -307,7 +307,8 @@ Interface (DBI)
     $dbh = DBI->connect($dsn, $user, $password);
 
 
-    @databases = DBD::mysql::dr->func($host, $port, '_ListDBs');
+    $drh = DBI->install_driver("mysql");
+    @databases = $drh->func($host, $port, '_ListDBs');
     @tables = $dbh->func( '_ListTables' );
 
     $sth = $dbh->prepare("SELECT * FROM foo WHERE bla");
@@ -451,7 +452,10 @@ location for the socket than that built into the client.
 
 =item B<ListDBs>
 
-    @dbs = $dbh->func("$hostname:$port", '_ListDBs');
+    $drh = DBI->install_driver("~~");
+    @dbs = $drh->func("$hostname:$port", "_ListDBs");
+    @dbs = $drh->func($hostname, $port, "_ListDBs");
+    @dbs = $dbh->func('_ListDBs');
 
 Returns a list of all databases managed by the mysql daemon or
 mSQL daemon running on C<$hostname>, port C<$port>. This method
